<?php

/**
 * Copyright © 2017 Filoblu S.r.l. All rights reserved.
 */

namespace FiloBlu\GaMeasurementProtocol\Model\Plugin;

/*
 * Load Additional Data when getting Order by OrderRepository 
 */

class OrderGet {

    /** @var \FiloBlu\OrderAdditionalData\Model\OrderDataFactory */
    protected $orderDataFactory;

    /** @var \Magento\Sales\Api\Data\OrderExtensionFactory */
    protected $orderExtensionFactory;

    /**
     * Init plugin
     *
     * @param \FiloBlu\OrderAdditionalData\Model\OrderDataFactory $orderDataFactory
     * @param \Magento\Sales\Api\Data\OrderExtensionFactory $orderExtensionFactory 
     */
    public function __construct(
    \FiloBlu\OrderAdditionalData\Model\OrderDataFactory $orderDataFactory, \Magento\Sales\Api\Data\OrderExtensionFactory $orderExtensionFactory
    ) {
        $this->orderDataFactory = $orderDataFactory;
        $this->orderExtensionFactory = $orderExtensionFactory;
    }

    /**
     * Add Data to order
     *
     * @param \Magento\Sales\Api\OrderRepositoryInterface $subject
     * @param \Magento\Sales\Api\Data\OrderInterface $resultOrder
     * @return \Magento\Sales\Api\Data\OrderInterface
     */
    public function afterGet(
    \Magento\Sales\Api\OrderRepositoryInterface $subject, \Magento\Sales\Api\Data\OrderInterface $resultOrder
    ) {
        $resultOrder = $this->getGaSessionIdData($resultOrder);
        return $resultOrder;
    }

    /**
     * set Ga Session Id Data additional data for order
     *
     * @param \Magento\Sales\Api\Data\OrderInterface $order
     * @return \Magento\Sales\Api\Data\OrderInterface
     */
    protected function getGaSessionIdData(\Magento\Sales\Api\Data\OrderInterface $order) {
        $extensionAttributes = $order->getExtensionAttributes();
        if ($extensionAttributes && $extensionAttributes->getPaymentFeeAmount()) {
            return $order;
        }
        /** @var \Magento\Sales\Api\Data\OrderExtension $orderExtension */
        $orderExtension = $extensionAttributes ? $extensionAttributes : $this->orderExtensionFactory->create();
        $orderExtension->setGaSessionId($order->getGaSessionId());
        $order->setExtensionAttributes($orderExtension);

        return $order;
    }

    /**
     * @param \Magento\Sales\Api\OrderRepositoryInterface $subject
     * @param \Magento\Sales\Model\ResourceModel\Order\Collection $resultOrder
     * @return \Magento\Sales\Model\ResourceModel\Order\Collection
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function afterGetList(
    \Magento\Sales\Api\OrderRepositoryInterface $subject, \Magento\Sales\Model\ResourceModel\Order\Collection $resultOrder
    ) {
        /** @var  $order */
        foreach ($resultOrder->getItems() as $order) {
            $this->afterGet($subject, $order);
        }
        return $resultOrder;
    }

}
